EULA - PIPython
Author: Physik Instrumente (PI) GmbH & Co. KG

# License Agreement

General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG

Issued: April 16, 2018

## Preamble

Physik Instrumente (PI) GmbH & Co. KG (hereinafter referred to as "PI") is a manufacturer and provider of micro- and nanopositioning technology and motion control systems, devices and apparatuses including their respective firmware (hereinafter jointly referred to as "the PI Hardware"), which can either be used independently or as an integral part of other third-party hardware systems. For the purpose of operating the PI Hardware, PI provides its customers, which either purchase the PI Hardware directly from PI for their own use or which integrate the PI Hardware into third-party hardware systems for distribution to their clients (hereinafter jointly referred to as "the Customer") with software products or tools (hereinafter jointly referred to as "the Software").

The following general terms and conditions (hereinafter referred to as "Terms and Conditions") shall apply to any Software provided by PI to the Customer, unless expressly agreed or stated otherwise herein, and may be supplemented by specific terms and conditions for individual software components.

## I. Scope

(1) These Terms and Conditions shall apply to the supply of Software for its use together with PI Hardware and the granting of rights of use to the Customer, as described below.

(2) The Software is supplied by PI to the Customer either in machine-readable form or with regard to certain software components in machine-readable form together with its source code and is subject to the following Terms and Conditions, unless PI and the Customer have agreed otherwise in writing.

(3) These Terms and Conditions shall not apply to the PI Hardware.

(4) PI does not owe any installation and configuration services under these Terms and Conditions.

(5) The Software is not designed for use in medical devices (Medizinprodukt) according to section 3 of the German Act on Medical Devices (MPG).

(6) References to the application of statutory provisions only serve clarification purposes. Therefore, the statutory provisions apply even without such clarification, unless modified directly by these Terms and Conditions.

## II. Rights of Use

(1) Unless stated otherwise herein, PI grants to the Customer a non-exclusive territorially unrestricted right to use the Software for an unlimited period of time on the basis of the following provisions.

(2) The following restrictions apply, if not explicitly agreed otherwise:

(i) The Customer shall be entitled to use the Software insofar as this is required for the contractually agreed or contractually intended use of the Software and in accordance with these Terms and Conditions, including the right to install the Software onto a hard disk drive and/or to load it into the random access memory (RAM). If not specified otherwise, the Customer is entitled to use the Software within its company on several devices or on several workstations simultaneously and to duplicate the Software for that purpose. In the event that the use of the Software depends on a prior activation and is therefore limited to a certain license key (to be individually purchased by the Customer from PI), the use of the affected Software shall however be restricted to the respective device for which the Software has been activated by the Customer. The Software shall in any case be used by the Customer exclusively for and in relation with the operation of PI Hardware. The Customer shall insofar however be entitled to use the Software together with third-party software or to combine the Software with third-party software products, as far as necessary to operate its or any third-party systems that do include the PI Hardware.

(ii) The Customer shall furthermore be entitled to generate application-specific, loadable and executable software products with the Software and to transfer such software products to third parties only for use for and in relation with the operation of PI Hardware. Such third party shall not be granted any rights of use beyond the rights of use granted to Customer under these Terms and Conditions. Moreover, the Customer shall contractually ensure that such third party shall be bound by the contractual obligations under these Terms and Conditions with regard to the software products.

(iii) The Customer shall be entitled to transfer the right of use granted hereunder to a third party, provided that such third party agrees to the continued validity of the rights of use for and in relation with the PI Hardware and that the Customer deletes any remaining copies of the Software without undue delay. Such a third party shall not be granted any rights of use beyond the rights of use granted to the Customer under these Terms and Conditions. Moreover, the Customer shall contractually ensure that such third party uses the Software in accordance with these Terms and Conditions and in particular solely for the purpose of operating the PI Hardware. Subparagraph (xii) shall remain unaffected.

(iv) The subleasing of the Software for commercial purposes is prohibited.

(v) The Customer shall not grant any sublicenses of the Software, unless stipulated otherwise in these Terms and Conditions.

(vi) The Customer shall not be entitled to modify, extend, reverse engineer, decompile, reverse assemble or disassemble Software delivered in machine-readable form (object code) unless it is necessary for the purpose of using the Software in accordance with its contractually agreed or contractually intended purpose, including the purpose of removing defects, or unless it is specifically permitted by law, particularly according to section 69a et sqq. of the German Copyright Act (UrhG), in any case only if PI does not provide the Customer with the required information or does not remove the defect within a reasonable period of time after having been requested to do so via an email sent by the Customer to service@pi.de.

(vii) If the Software or parts thereof are provided together with its source code, the Customer shall be entitled to modify the Software on the basis of the source code and to use the modified source code solely for the purpose of operating the PI Hardware and/or third-party systems that include the PI Hardware in accordance with these Terms and Conditions; provided, however, that the Customer shall always include in any such modification a brief summary of the changes made to the source code and the date of the modification. Subject to clause IV, PI shall not be held responsible for any claims resulting from such modification of the source code.

(viii) Copyright notes, serial numbers as well as further characteristics for identification shall not be removed from the Software and copies thereof.

(ix) PI may provide the Customer with Software which includes or may be used together with third-party software (including freeware and open source software components). PI informs the Customer about the third-party software used and provides the Customer with the corresponding license terms within the Third Party Software Note (http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf) to the extent requested by the respective licensor. With regard to third-party software listed in the Third Party Software Note, the respective license terms, which the third-party software is subject to, shall apply. In case of a breach of the third-party license terms, the respective licensor may also be entitled to make subsequent claims and rights in its own name.

(x) If PI provides the Customer with amendments (patches, bug fixes, amendments to the manual etc.) or a new edition (updates, upgrades) of the Software within the scope of rectification or maintenance, which replace the originally provided Software, those are subject to these Terms and Conditions.

(xi) In the event that PI provides the Customer with a test version of the Software, these Terms and Conditions apply accordingly, however, except that the Customer is granted with a right to use the Software, which is limited to the defined test period.

(xii) A temporary use of the Software by a third person, who integrates the Software and PI Hardware with other products on behalf of the Customer, is considered as use by the Customer's company. Such third party shall use the Software only within the time period required for the integration or for providing support services to the Customer and shall be bound in accordance with the contractual obligations under these Terms and Conditions.

## III. Rectification in case of defects

(1) Definitions

(i) The Software shall be deemed as defective in quality in the event that it does not show the contractually stipulated condition or it does not fit the contractually stipulated purpose.

(ii) The Software is subject to proprietary rights (particularly copyrights) of PI and/or third parties. It constitutes a defect in title if required rights for the contract-based usage could not be legally granted to the Customer.

(2) Statute of limitations

(i) The statute of limitations for claims of defects is 12 months, calculated from the date of the delivery of the Software.

(ii) This does not apply in the event of actions of PI or its representatives or vicarious agents (Erfuellungsgehilfen) in bad faith or in relation to guarantees granted.

(3) Modifications to the Software by the Customer

As far as the Customer modifies the Software or has it modified by third parties, claims regarding defects in quality or title shall be invalidated, unless the Customer proofs that the defect was not caused by the modifications and also if the analysis and the removal of the defect is not affected by the modification.

(4) Obligations to examine and notify defects

(i) After delivery of the Software to the Customer, the Customer shall examine the Software for completeness and possible defects without undue delay, insofar as this is feasible in the orderly course of business, and notify PI immediately of any complaints. Otherwise, claims of the Customer as defined in the following clauses shall be excluded in relation to such defects in quality that would have been obvious within a properly conducted examination.

(ii) Together with the notification of the defect, the Customer has to provide PI with comprehensible documentation thereof.

(5) Supplementary performance (Nacherfuellung)

(i) PI may rectify the defect by reworking the Software (Nachbesserung) or by supplying a replacement, as it chooses. The Customer may request within a reasonable time period a reworking or a supply of a replacement of the Software, if another type of supplementary performance is unreasonable.

(ii) Alternatively, PI can rectify the defect by providing instructions electronically, by phone, in writing or by providing updates for download on its homepage to the Customer.

(6) Measures in the event of alleged defects in title

(i) Should a third party raise claims against the Customer based on the allegation that the Software or the designation of the Software infringes its intellectual property rights, the Customer will notify PI immediately thereof and entrust PI with the defense against the alleged claims as far as possible. The Customer will provide to PI any reasonable support in this regard.

(ii) PI can remedy a defect in title by providing the Customer with a legally unchallengeable option to use either the Software or a legally unchallengeable modification of the Software, at its sole discretion.

If not stipulated otherwise, the regulations of this clause also remain applicable equivalently in relations to defects in title.

(7) PI shall provide its services subject to the supplementary performance within a reasonable period.

(8) Bad faith (Arglist), guarantees

Statutory claims of the Customer remain unaffected in case of actions of PI or its representatives or vicarious agents in bad faith or in relation to guarantees granted. The stipulations of clause IV shall remain unaffected by this clause III.

## IV. Limitation of Liability

PI only assumes liability under the following conditions:

(1) For damage caused by PI or any of its legal representatives, executive staff or vicarious agents through willful intent or gross negligence, PI is liable without restriction.

(2) PI is not liable for any violation of insignificant contractual obligations by minor negligence. With regard to a violation of essential contractual obligations (i.e. obligations which the contractual partner can expect to be fulfilled and the fulfilment of which is required for the due execution of the contract) PI's liability for damage caused by minor negligence is limited to anticipated damage typical to contracts of this kind (vertragstypisch vorhersehbare Schaeden). The same applies to violations of obligations through minor negligence committed by legal representatives, executive staff or vicarious agents of PI.

(3) No license fee is charged to the Customer by PI for the use of any open source or freeware software component / product. Regarding such components / products, the Customer hereby accepts the application of the corresponding license terms which are attached in the Third Party Software Note (http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf). To the extent that there is a conflict between these Terms and Conditions and the respective license terms, the license terms shall prevail over these Terms and Conditions with regard to the respective open source or freeware software component / product. However, PI's liability for willful intent and gross negligence remains unaffected.

(4) Notwithstanding the foregoing, contributory negligence of the Client diminishes the amount of any claims for damages, especially if caused by insufficient cooperation, organizational errors, insufficient data protection or a breach of other contractual duties.

(5) The Customer is responsible to back up his data regularly. In the event of a loss of data caused by PI, the liability of PI is limited to the costs of reproducing the lost data on the basis of the backups that the Customer was under the obligation to conduct and for costs for reproducing data that would have been also lost, even if the Customer had conducted regular backups.

(6) The aforementioned limitation of liability does not apply in the event of fraudulent intent, injury to life, body and health, breach of warranty, and claims based on the German Product Liability Act (ProduktHaftG).

## V. Final Provisions

(1) The place of performance for deliveries shall be the registered office (Sitz) of PI.

(2) The district court of Karlsruhe (Landgericht Karlsruhe) shall have jurisdiction over all disputes arising from or in connection with these Terms and Conditions. PI shall, however, be entitled to assert claims at the registered seat of the Customer.

(3) The laws of Germany shall apply. International purchase laws shall not apply. This shall, in particular, refer to the UN Convention (CISG) on the International Sale of Goods.

(4) The invalidity or unenforceability of any provision of these Terms and Conditions shall not affect the validity and enforceability of the other provisions. Invalid or unenforceable provisions shall be deemed to be replaced by such valid and enforceable provisions that shall be suitable to implement the economic purpose of the deleted provision to the greatest extent possible. The same applies for omissions.

« Previous